@@ -55,7 +55,7 @@ class CoreAuthModPDO extends CoreAuthModule {
         $config = $this->getConfig();
         if(!$this->DB->open($config['driver'], $config['params'], $config['username'], $config['password'])) {
             throw new NagVisException(l('Unable to open auth database ([DB]): [MSG]',
-                Array('DB' => $this->DB->dsn,
+                Array('DB' => $this->DB->getDSN(),
                       'MSG' => json_encode($this->DB->error()))));
         } else {
             // Create initial db scheme if needed
